<?php

namespace Litecms\Bapsplan\Providers;

use Illuminate\Support\ServiceProvider;

class BapsplanServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'bapsplan');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'bapsplan');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.bapsplan', function ($app) {
            return $this->app->make('Litecms\Bapsplan\Bapsplan');
        });

                // Bind Bapplan to repository
        $this->app->bind(
            'Litecms\Bapsplan\Interfaces\BapplanRepositoryInterface',
            \Litecms\Bapsplan\Repositories\Eloquent\BapplanRepository::class
        );

        $this->app->register(\Litecms\Bapsplan\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\Bapsplan\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.bapsplan'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/bapsplan.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/bapsplan')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/bapsplan')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
